use super::helpers;
use bson::doc;
use log::{trace, warn};
use wccg_models::activity::ActivityType;
use wccg_models::activity::RiderMonthlySummary;
use wccg_models::any::Any;
use wread_data_mongodb::crud_repository;
use wread_data_mongodb::mongodb::Database;

const COLLECTION_NAME: &str = "riderMonthlySummary";

pub fn increment_activity_stats(
    rider_id: &String,
    year: i32,
    month: i32,
    activity_type: &ActivityType,
    distance: f32,
    count: i32,
    commute_distance: f32,
    commute_count: i32,
    db: &Database,
) {
    trace!("increment_activity_stats");
    init_rider_summary(rider_id, year, month, db);

    if let Some(update_document) =
        helpers::get_activity_stats_update_document(activity_type, distance, count, commute_distance, commute_count)
    {
        crud_repository::update_one(
            doc! {"riderId": rider_id, "year": year, "month": month},
            update_document,
            None,
            COLLECTION_NAME,
            db,
        )
        .unwrap();
    } else {
        warn!("None from get_activity_stats_update_document");
    }
}

fn init_rider_summary(rider_id: &String, year: i32, month: i32, db: &Database) {
    let rider_summary = crud_repository::find_one::<Any>(
        doc! {"riderId": rider_id, "year": year, "month": month},
        COLLECTION_NAME,
        db,
    )
    .unwrap();

    if let None = rider_summary {
        let mut empty_rider_summary = RiderMonthlySummary::default();
        empty_rider_summary.set_rider_id(rider_id.to_owned());
        empty_rider_summary.set_year(year);
        empty_rider_summary.set_month(month);
        crud_repository::add(&empty_rider_summary, COLLECTION_NAME, db).unwrap();
    }
}
